@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-
 from branca.element import MacroElement
+from jinja2 import Template
 
 from folium.elements import JSCSSMixin
 
-from jinja2 import Template
-
 
 class Terminator(JSCSSMixin, MacroElement):
     """
@@ -13,17 +10,17 @@ class Terminator(JSCSSMixin, MacroElement):
     overlay day and night regions on maps.
 
     """
-    _template = Template(u"""
+
+    _template = Template(
+        """
         {% macro script(this, kwargs) %}
             L.terminator().addTo({{this._parent.get_name()}});
         {% endmacro %}
-        """)
+        """
+    )
 
-    default_js = [
-        ('terminator',
-         'https://unpkg.com/@joergdietrich/leaflet.terminator')
-    ]
+    default_js = [("terminator", "https://unpkg.com/@joergdietrich/leaflet.terminator")]
 
     def __init__(self):
-        super(Terminator, self).__init__()
-        self._name = 'Terminator'
+        super().__init__()
+        self._name = "Terminator"
